==> qtjambi-qml-debuginfo-macos-6.6.0.jar: sources/QtJambiQml/QQmlAbstractUrlInterceptor_shell.cpp <==
#include "QQmlAbstractUrlInterceptor_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlAbstractUrlInterceptor(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlAbstractUrlInterceptor")
    QQmlAbstractUrlInterceptor *_ptr = reinterpret_cast<QQmlAbstractUrlInterceptor *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlAbstractUrlInterceptor_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlAbstractUrlInterceptor_shell) ); }

jmethodID QQmlAbstractUrlInterceptor_shell::__shell_javaMethod(int pos) const { return QQmlAbstractUrlInterceptor_shell::__shell()->javaMethod(typeid(QQmlAbstractUrlInterceptor), pos); }

// emitting (writeShellConstructor)
QQmlAbstractUrlInterceptor_shell::QQmlAbstractUrlInterceptor_shell()
    : QQmlAbstractUrlInterceptor()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlAbstractUrlInterceptor::QQmlAbstractUrlInterceptor_shell()", QQmlAbstractUrlInterceptor_shell::__shell())
    QQmlAbstractUrlInterceptor_shell::__shell()->constructed(typeid(QQmlAbstractUrlInterceptor));
}

// emitting (writeShellDestructor)
QQmlAbstractUrlInterceptor_shell::~QQmlAbstractUrlInterceptor_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlAbstractUrlInterceptor::~QQmlAbstractUrlInterceptor()", QQmlAbstractUrlInterceptor_shell::__shell())
    QQmlAbstractUrlInterceptor_shell::__shell()->destructed(typeid(QQmlAbstractUrlInterceptor));
}

void QQmlAbstractUrlInterceptor_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlAbstractUrlInterceptor_shell*>(ptr)->QQmlAbstractUrlInterceptor_shell::__shell()->tryDeleteShell(typeid(QQmlAbstractUrlInterceptor));
}

// emitting Virtual overrides (virtualFunctions)
QUrl QQmlAbstractUrlInterceptor_shell::intercept(const QUrl& path0, QQmlAbstractUrlInterceptor::DataType type1)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlAbstractUrlInterceptor::", QQmlAbstractUrlInterceptor_shell::__shell())
        if(JniEnvironment __jni_env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QUrl  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlAbstractUrlInterceptor_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_path0 = qtjambi_cast<jobject>(__jni_env, path0);
                    jobject __java_type1 = qtjambi_cast<jobject>(__jni_env, type1);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_path0, __java_type1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QUrl >(__jni_env, __java_return_value);
                } else {
                    QQmlAbstractUrlInterceptor_shell::__shell()->warnForMethod("QQmlAbstractUrlInterceptor::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QQmlAbstractUrlInterceptor::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QUrl();
        }
    }else{
        return QUrl();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QQmlAbstractUrlInterceptor_access::__qt_intercept_cref_QUrl_QQmlAbstractUrlInterceptor_DataType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID path0, jint type1)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const QUrl& __qt_path0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(path0);
    QQmlAbstractUrlInterceptor::DataType __qt_type1 = qtjambi_cast<QQmlAbstractUrlInterceptor::DataType>(__jni_env, type1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlAbstractUrlInterceptor::intercept(const QUrl & path, QQmlAbstractUrlInterceptor::DataType type)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlAbstractUrlInterceptor::intercept(const QUrl & path, QQmlAbstractUrlInterceptor::DataType type).";
    } else {
        QUrl __qt_return_value = intercept(__qt_path0, __qt_type1);
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QQmlAbstractUrlInterceptor_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QQmlAbstractUrlInterceptor *__qt_this = new(__qtjambi_ptr) QQmlAbstractUrlInterceptor_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QQmlAbstractUrlInterceptor_shell
void __qt_destruct_QQmlAbstractUrlInterceptor(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlAbstractUrlInterceptor")
    reinterpret_cast<QQmlAbstractUrlInterceptor_shell*>(ptr)->~QQmlAbstractUrlInterceptor_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlAbstractUrlInterceptor::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlAbstractUrlInterceptor_00024Impl_initialize_1native__Lio_qt_qml_QQmlAbstractUrlInterceptor_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlAbstractUrlInterceptor::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlAbstractUrlInterceptor_0, sizeof(QQmlAbstractUrlInterceptor_shell), typeid(QQmlAbstractUrlInterceptor), true, &deleter_QQmlAbstractUrlInterceptor, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlAbstractUrlInterceptor::intercept(QUrl,QQmlAbstractUrlInterceptor::DataType)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlAbstractUrlInterceptor_00024Impl_00024ConcreteWrapper_intercept_1native_1cref_1QUrl_1QQmlAbstractUrlInterceptor_1DataType__JJI)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID path0,
 jint type1)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QQmlAbstractUrlInterceptor *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlAbstractUrlInterceptor>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlAbstractUrlInterceptor::intercept(QUrl,QQmlAbstractUrlInterceptor::DataType)", __qt_this)
        __java_return_value = static_cast<QQmlAbstractUrlInterceptor_access*>(__qt_this)->__qt_intercept_cref_QUrl_QQmlAbstractUrlInterceptor_DataType(__jni_env, __this_nativeId, path0, type1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlAbstractUrlInterceptor(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlAbstractUrlInterceptor>("QQmlAbstractUrlInterceptor", "io/qt/qml/QQmlAbstractUrlInterceptor");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "intercept", "(Lio/qt/core/QUrl;Lio/qt/qml/QQmlAbstractUrlInterceptor$DataType;)Lio/qt/core/QUrl;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QQmlAbstractUrlInterceptor, {
        ConstructorInfo(&__qt_construct_QQmlAbstractUrlInterceptor_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlAbstractUrlInterceptor);
    registerSizeOfShell(typeId, sizeof(QQmlAbstractUrlInterceptor_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlAbstractUrlInterceptor* _object = dynamic_cast<QQmlAbstractUrlInterceptor*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlAbstractUrlInterceptor *object = reinterpret_cast<QQmlAbstractUrlInterceptor *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlAbstractUrlInterceptor *object = reinterpret_cast<const QQmlAbstractUrlInterceptor *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QQmlAbstractUrlInterceptor::DataType>("QQmlAbstractUrlInterceptor::DataType", "io/qt/qml/QQmlAbstractUrlInterceptor$DataType");
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.6.3.jar: sources/QtJambiQml/QQmlAbstractUrlInterceptor_shell.cpp <==
#include "QQmlAbstractUrlInterceptor_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlAbstractUrlInterceptor(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlAbstractUrlInterceptor")
    QQmlAbstractUrlInterceptor *_ptr = reinterpret_cast<QQmlAbstractUrlInterceptor *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlAbstractUrlInterceptor_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlAbstractUrlInterceptor_shell) ); }

jmethodID QQmlAbstractUrlInterceptor_shell::__shell_javaMethod(int pos) const { return QQmlAbstractUrlInterceptor_shell::__shell()->javaMethod(typeid(QQmlAbstractUrlInterceptor), pos); }

// emitting (writeShellConstructor)
QQmlAbstractUrlInterceptor_shell::QQmlAbstractUrlInterceptor_shell()
    : QQmlAbstractUrlInterceptor()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlAbstractUrlInterceptor::QQmlAbstractUrlInterceptor_shell()", QQmlAbstractUrlInterceptor_shell::__shell())
    QQmlAbstractUrlInterceptor_shell::__shell()->constructed(typeid(QQmlAbstractUrlInterceptor));
}

// emitting (writeShellDestructor)
QQmlAbstractUrlInterceptor_shell::~QQmlAbstractUrlInterceptor_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlAbstractUrlInterceptor::~QQmlAbstractUrlInterceptor()", QQmlAbstractUrlInterceptor_shell::__shell())
    QQmlAbstractUrlInterceptor_shell::__shell()->destructed(typeid(QQmlAbstractUrlInterceptor));
}

void QQmlAbstractUrlInterceptor_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlAbstractUrlInterceptor_shell*>(ptr)->QQmlAbstractUrlInterceptor_shell::__shell()->tryDeleteShell(typeid(QQmlAbstractUrlInterceptor));
}

// emitting Virtual overrides (virtualFunctions)
QUrl QQmlAbstractUrlInterceptor_shell::intercept(const QUrl& path0, QQmlAbstractUrlInterceptor::DataType type1)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlAbstractUrlInterceptor::", QQmlAbstractUrlInterceptor_shell::__shell())
        if(JniEnvironment __jni_env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QUrl  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlAbstractUrlInterceptor_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_path0 = qtjambi_cast<jobject>(__jni_env, path0);
                    jobject __java_type1 = qtjambi_cast<jobject>(__jni_env, type1);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_path0, __java_type1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QUrl >(__jni_env, __java_return_value);
                } else {
                    QQmlAbstractUrlInterceptor_shell::__shell()->warnForMethod("QQmlAbstractUrlInterceptor::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QQmlAbstractUrlInterceptor::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QUrl();
        }
    }else{
        return QUrl();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QQmlAbstractUrlInterceptor_access::__qt_intercept_cref_QUrl_QQmlAbstractUrlInterceptor_DataType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID path0, jint type1)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const QUrl& __qt_path0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(path0);
    QQmlAbstractUrlInterceptor::DataType __qt_type1 = qtjambi_cast<QQmlAbstractUrlInterceptor::DataType>(__jni_env, type1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlAbstractUrlInterceptor::intercept(const QUrl & path, QQmlAbstractUrlInterceptor::DataType type)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlAbstractUrlInterceptor::intercept(const QUrl & path, QQmlAbstractUrlInterceptor::DataType type).";
    } else {
        QUrl __qt_return_value = intercept(__qt_path0, __qt_type1);
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QQmlAbstractUrlInterceptor()
void __qt_construct_QQmlAbstractUrlInterceptor(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlAbstractUrlInterceptor()")
    Q_UNUSED(__java_arguments)
    QQmlAbstractUrlInterceptor *__qt_this = new(__qtjambi_ptr) QQmlAbstractUrlInterceptor_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QQmlAbstractUrlInterceptor::QQmlAbstractUrlInterceptor()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlAbstractUrlInterceptor_00024Impl_initialize_1native__Lio_qt_qml_QQmlAbstractUrlInterceptor_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlAbstractUrlInterceptor::QQmlAbstractUrlInterceptor()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlAbstractUrlInterceptor, sizeof(QQmlAbstractUrlInterceptor_shell), typeid(QQmlAbstractUrlInterceptor), true, &deleter_QQmlAbstractUrlInterceptor, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlAbstractUrlInterceptor_shell
void __qt_destruct_QQmlAbstractUrlInterceptor(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlAbstractUrlInterceptor")
    reinterpret_cast<QQmlAbstractUrlInterceptor_shell*>(ptr)->~QQmlAbstractUrlInterceptor_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlAbstractUrlInterceptor::intercept(QUrl,QQmlAbstractUrlInterceptor::DataType)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlAbstractUrlInterceptor_00024Impl_00024ConcreteWrapper_intercept_1native_1cref_1QUrl_1QQmlAbstractUrlInterceptor_1DataType__JJI)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID path0,
 jint type1)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QQmlAbstractUrlInterceptor *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlAbstractUrlInterceptor>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlAbstractUrlInterceptor::intercept(QUrl,QQmlAbstractUrlInterceptor::DataType)", __qt_this)
        __java_return_value = static_cast<QQmlAbstractUrlInterceptor_access*>(__qt_this)->__qt_intercept_cref_QUrl_QQmlAbstractUrlInterceptor_DataType(__jni_env, __this_nativeId, path0, type1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlAbstractUrlInterceptor(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlAbstractUrlInterceptor>("QQmlAbstractUrlInterceptor", "io/qt/qml/QQmlAbstractUrlInterceptor");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "intercept", "(Lio/qt/core/QUrl;Lio/qt/qml/QQmlAbstractUrlInterceptor$DataType;)Lio/qt/core/QUrl;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QQmlAbstractUrlInterceptor, {
        ConstructorInfo(&__qt_construct_QQmlAbstractUrlInterceptor, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlAbstractUrlInterceptor);
    registerSizeOfShell(typeId, sizeof(QQmlAbstractUrlInterceptor_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlAbstractUrlInterceptor* _object = dynamic_cast<QQmlAbstractUrlInterceptor*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlAbstractUrlInterceptor *object = reinterpret_cast<QQmlAbstractUrlInterceptor *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlAbstractUrlInterceptor *object = reinterpret_cast<const QQmlAbstractUrlInterceptor *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QQmlAbstractUrlInterceptor::DataType>("QQmlAbstractUrlInterceptor::DataType", "io/qt/qml/QQmlAbstractUrlInterceptor$DataType");
// END: enums and flags
}
